/*********************************************************************

 Author        : ADI - Apps            www.analog.com/MicroConverter

 Date          : Jun. 05

 File          : PowerDown.c

 Hardware      : ADuC7026

 Description   : The part is powered down by writing 0x40 to the POWCON 
 				 register. The part is then inactive until XIRQ is pressed. 
				 This causes an interrupt to occur. Once the interupt 
				 routine has been executed, the part reamins powered on and 
				 runs as normal.	

				 Note: P1.4 must be tied to groun to prevent it causing a 
				 	   continuous interupt.	
		
*********************************************************************/

#include <ADuC7026.h>					// 	Include ADuC7026 Header File

void IRQ_Handler(void) __irq;			//	IRQ Funtion Prototype 
void delay(int);
										// 	Memory function macro 
int main (void)  {

	IRQEN = XIRQ0_BIT|SPM4_IO_BIT;		//	Enable XIRQ0 in IRQEnable 

	GP0CON = 0x00;
	GP4DAT = 0x04000000;				//	Configure P4.2 as output
	GP2DAT = 0xff000000;				//	Configure port 2 as output 

	POWKEY1 = 0x01;
	POWCON = 0x40;
	POWKEY2 = 0xF4;	

	while(1)
	{
		GP2DAT ^= 0x00ff0000;	   		// 	Complement Port 2
		delay(10000);					//	Delay to make blink visible
	}
                   
	return 0 ;
}

/********************************************************************/
/*                                                                  */
/*		Interrupt Service Rountine									*/
/*                                                                  */
/********************************************************************/

void IRQ_Handler() __irq
{
	GP4DAT ^= 0x00040000;				// Complement P4.2
	while(GP0DAT & 0x00010){}			// wait for XIRQ to be low again
	return ;
}

void delay (int length)
{
	while (length >=0)
    	length--;
}
